.. image:: https://sonarcloud.io/api/project_badges/measure?project=wuan_txjsonrpc&metric=alert_status
    :alt: Quality gate
    :target: https://sonarcloud.io/project/overview?id=wuan_txjsonrpc
.. image:: https://sonarcloud.io/api/project_badges/measure?project=wuan_txjsonrpc&metric=ncloc
    :alt: Lines of code
    :target: https://sonarcloud.io/project/overview?id=wuan_txjsonrpc
.. image:: https://sonarcloud.io/api/project_badges/measure?project=wuan_txjsonrpc&metric=coverage
    :alt: Coverage
    :target: https://sonarcloud.io/project/overview?id=wuan_txjsonrpc
.. image:: https://sonarcloud.io/api/project_badges/measure?project=wuan_txjsonrpc&metric=reliability_rating
    :alt: Reliability rating
    :target: https://sonarcloud.io/project/overview?id=wuan_txjsonrpc
.. image:: https://api.scorecard.dev/projects/github.com/wuan/txjsonrpc/badge
    :alt: OpenSSF Scorecard
    :target: https://scorecard.dev/viewer/?uri=github.com/wuan/txjsonrpc

============
txjsonrpc
============

------------
Introduction
------------

txJSON-RPC allows you to create async Python JSON-RPC servers and clients
either over HTTP or directly on TCP with the Netstring protocol. txJSON-RPC is
written in Twisted.

--------
Features
--------

* Asynchronous JSON-RPC server and client code.

* Support for HTTP and TCP (Netstring) JSON-RPC.

* A jsonrpclib similar to the one for XLM-RPC offered by the Python standard
  library.
